@@ -3,6 +3,9 @@
 
 from learnergy.models.bernoulli.rbm import RBM
 from learnergy.models.bernoulli.conv_rbm import ConvRBM
-from learnergy.models.bernoulli.discriminative_rbm import DiscriminativeRBM, HybridDiscriminativeRBM
-from learnergy.models.bernoulli.dropout_rbm import DropoutRBM, DropConnectRBM
+from learnergy.models.bernoulli.discriminative_rbm import (
+    DiscriminativeRBM,
+    HybridDiscriminativeRBM,
+)
+from learnergy.models.bernoulli.dropout_rbm import DropConnectRBM, DropoutRBM
 from learnergy.models.bernoulli.e_dropout_rbm import EDropoutRBM
