@@ -1,4 +1,4 @@
 """A package contaning additional RBM-based models (networks) for all common learnergy modules.
 """
 
-from learnergy.models.extra.sigmoid_rbm import SigmoidRBM, SigmoidRBM4deep
+from learnergy.models.extra.sigmoid_rbm import SigmoidRBM, SigmoidRBM4Deep
