@@ -1,7 +1,10 @@
 """A package contaning gaussian-valued models (networks) for all common learnergy modules.
 """
 
-from learnergy.models.gaussian.gaussian_conv_rbm import GaussianConvRBM, GaussianConvRBM4deep
+from learnergy.models.gaussian.gaussian_conv_rbm import (
+    GaussianConvRBM,
+    GaussianConvRBM4Deep,
+)
 from learnergy.models.gaussian.gaussian_rbm import (
     GaussianRBM,
     GaussianRBM4deep,
